[![PyPI Latest Release](https://img.shields.io/pypi/v/lighttree.svg)](https://pypi.org/project/lighttree/)
[![License](https://img.shields.io/pypi/l/lighttree.svg)](https://github.com/leonardbinet/lighttree/blob/master/LICENSE)
![Python package](https://github.com/leonardbinet/lighttree/workflows/Python%20package/badge.svg)


## What is it?

**lighttree** is a Python package providing a simple interface to manipulate data having a tree structure.


## Features

- multiple tree update methods
- ascii display
- interactive tree with autocompletion feature (for ipython usage)

## Documentation

Full documentation available (work in progress) [here on read-the-docs](https://lighttree.readthedocs.io/en/latest/).


## Installation
```
pip install lighttree
```

## Contributing

All contributions, bug reports, bug fixes, documentation improvements, enhancements and ideas are welcome.
